@@ -27,7 +27,7 @@ from .utils import (
     run_in_folder,
 )
 
-CC = ccompiler.new_compiler().executables["compiler"][0]
+CC = os.environ.get("CC", ccompiler.new_compiler().executables["compiler"][0])
 HERE = os.path.dirname(os.path.abspath(__file__))
 
 
@@ -56,6 +56,7 @@ def compile_if_needed(target_folder):
                 universal_newlines=True,
             )
             print(output)
+
             o_files = glob.glob("*.o")
             output = subprocess.check_output(
                 [
