@@ -88,7 +88,8 @@ static integer c__303 = 303;
 	y, doublereal *t, doublereal *tout, integer *itol, doublereal *rtol, 
 	doublereal *atol, integer *itask, integer *istate, integer *iopt, 
 	doublereal *rwork, integer *lrw, integer *iwork, integer *liw, U_fp 
-	jac, integer *jt, U_fp lu_solver__, U_fp fnorm_computation__)
+	jac, integer *jt, U_fp lu_solver__, U_fp fnorm_computation__, U_fp 
+	step_size_callback__, longint *handle)
 {
     /* Initialized data */
 
@@ -131,7 +132,7 @@ static integer c__303 = 303;
     extern /* Subroutine */ int stoda_(integer *, doublereal *, doublereal *, 
 	    integer *, doublereal *, doublereal *, doublereal *, doublereal *,
 	     doublereal *, integer *, S_fp, U_fp, U_fp, U_fp, U_fp, 
-	    doublereal *, U_fp, U_fp);
+	    doublereal *, U_fp, U_fp, U_fp, longint *);
     static integer imxer;
     static doublereal tcrit;
     static integer lenrw;
@@ -1159,7 +1160,6 @@ static integer c__303 = 303;
 /* not yet been done, an error return occurs. */
 /* if istate = 1 and tout = t, jump to block g and return immediately. */
 /* ----------------------------------------------------------------------- */
-/*      write(*, *) 'neq', neq */
 /*      write(*, *) 't', t */
 /*      write(*, *) 'tout', tout */
 /*      write(*, *) 'itol', itol */
@@ -1802,7 +1802,8 @@ L290:
 	    ls0001_1.lyh], &rwork[ls0001_1.lewt], &rwork[ls0001_1.lsavf], &
 	    rwork[ls0001_1.lacor], &rwork[ls0001_1.lwm], &iwork[ls0001_1.liwm]
 	    , (S_fp)f, (U_fp)jac, (U_fp)prja_, (U_fp)solsy_, (U_fp)econ, &
-	    rwork[llasty], (U_fp)lu_solver__, (U_fp)fnorm_computation__);
+	    rwork[llasty], (U_fp)lu_solver__, (U_fp)fnorm_computation__, (
+	    U_fp)step_size_callback__, handle);
 /*     SCIPY error check: */
     if (neq[1] == -1) {
 	return 0;
