@@ -41,7 +41,7 @@ static integer c__1 = 1;
 	integer *nyh, doublereal *yh1, doublereal *ewt, doublereal *savf, 
 	doublereal *acor, doublereal *wm, integer *iwm, S_fp f, U_fp jac, 
 	S_fp pjac, U_fp slvs, U_fp econ, doublereal *lasty, S_fp lu_solver__, 
-	real *fnorm_computation__)
+	real *fnorm_computation__, S_fp step_size_callback__, longint *handle)
 {
     /* Initialized data */
 
@@ -383,7 +383,7 @@ L220:
 	y[i__] = yh[i__ + yh_dim1];
     }
     srcma_(rsav, isav, &c__1);
-/*     write(*, *), "call f 258" */
+/*     write(*, *), "call f 258", tn */
     (*f)(&neq[1], &ls0001_1.tn, &y[1], &savf[1]);
 /*     SCIPY error check: */
     if (neq[1] == -1) {
@@ -627,6 +627,7 @@ L450:
     iredo = 0;
     ++ls0001_1.nst;
     ls0001_1.hu = ls0001_1.h__;
+    (*step_size_callback__)(handle, &ls0001_1.h__);
     ls0001_1.nqu = ls0001_1.nq;
     lsa001_1.mused = ls0001_1.meth;
     i__2 = ls0001_1.l;
