@@ -628,7 +628,7 @@ def _gsl_related_c_code():
         |#define BUFFER_SIZE_ERROR_MESSAGE 9999
         |
         |#define APPEND(buffer, buffer_size, what) do {\\
-        |    strncat(buffer, what, buffer_size - strlen(buffer));\\
+        |    strncat(buffer, what, buffer_size - strlen(buffer) - 1);\\
         |    } while(0)
         |
         |static char last_error_message[BUFFER_SIZE_ERROR_MESSAGE] = "";
